@@ -2,5 +2,5 @@
 # Copyright 2022 Canonical Ltd.
 # See LICENSE file for licensing details.
 
-from .parse import Parser
+from .parse import Parser, ParserException
 from .readonlydict import readonlydict
